Your code here initialize kernal
| 8 | // Your code here |
| 9 | // initialize kernal |
| 10 | __global__ void MarkRowKernel(int* row, int* col, size_s start, size_s end, size_l nnz, int* flag){ |
| 11 | size_l i = blockIdx.x * blockDim.x + threadIdx.x; |
| 12 | if(i < nnz){ |
| 13 | if(row[i] >= start && row[i] <= end){ |
| 14 | flag[i] = 1; |
| 15 | } |
| 16 | } |
| 17 | } |
| 18 | |
| 19 | // initialize kernal |
| 20 | __global__ void MarkColKernel(int* row, int* col, size_s start, size_s end, size_l nnz, int* flag){ |
nothing calls this directly
no outgoing calls
no test coverage detected